/* Base.c generated by valac 0.56.19, the Vala compiler
 * generated from Base.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE (tuba_views_admin_page_base_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBase))
#define TUBA_VIEWS_ADMIN_PAGE_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBaseClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE))
#define TUBA_VIEWS_ADMIN_PAGE_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBaseClass))

typedef struct _TubaViewsAdminPageBase TubaViewsAdminPageBase;
typedef struct _TubaViewsAdminPageBaseClass TubaViewsAdminPageBaseClass;
typedef struct _TubaViewsAdminPageBasePrivate TubaViewsAdminPageBasePrivate;

#define TUBA_DIALOGS_ADMIN_TYPE_WINDOW (tuba_dialogs_admin_window_get_type ())
#define TUBA_DIALOGS_ADMIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindow))
#define TUBA_DIALOGS_ADMIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindowClass))
#define TUBA_DIALOGS_ADMIN_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW))
#define TUBA_DIALOGS_ADMIN_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_ADMIN_TYPE_WINDOW))
#define TUBA_DIALOGS_ADMIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindowClass))

typedef struct _TubaDialogsAdminWindow TubaDialogsAdminWindow;
typedef struct _TubaDialogsAdminWindowClass TubaDialogsAdminWindowClass;
enum  {
	TUBA_VIEWS_ADMIN_PAGE_BASE_0_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_BASE_PAGE_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_BASE_ADMIN_WINDOW_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_BASE_SPINNING_PROPERTY,
	TUBA_VIEWS_ADMIN_PAGE_BASE_NUM_PROPERTIES
};
static GParamSpec* tuba_views_admin_page_base_properties[TUBA_VIEWS_ADMIN_PAGE_BASE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _TubaViewsAdminPageBase {
	AdwNavigationPage parent_instance;
	TubaViewsAdminPageBasePrivate * priv;
	AdwHeaderBar* headerbar;
	AdwToolbarView* toolbar_view;
};

struct _TubaViewsAdminPageBaseClass {
	AdwNavigationPageClass parent_class;
	void (*add_to_page) (TubaViewsAdminPageBase* self, AdwPreferencesGroup* group);
};

struct _TubaViewsAdminPageBasePrivate {
	GtkWidget* _page;
	GtkScrolledWindow* scroller;
	AdwSpinner* spinner;
	AdwToastOverlay* toast_overlay;
	TubaDialogsAdminWindow* _admin_window;
	gboolean _spinning;
};

static gint TubaViewsAdminPageBase_private_offset;
static gpointer tuba_views_admin_page_base_parent_class = NULL;

VALA_EXTERN GType tuba_views_admin_page_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageBase, g_object_unref)
VALA_EXTERN GType tuba_dialogs_admin_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsAdminWindow, g_object_unref)
VALA_EXTERN void tuba_views_admin_page_base_add_to_page (TubaViewsAdminPageBase* self,
                                             AdwPreferencesGroup* group);
static void tuba_views_admin_page_base_real_add_to_page (TubaViewsAdminPageBase* self,
                                                  AdwPreferencesGroup* group);
VALA_EXTERN GtkWidget* tuba_views_admin_page_base_get_page (TubaViewsAdminPageBase* self);
VALA_EXTERN void tuba_views_admin_page_base_add_toast (TubaViewsAdminPageBase* self,
                                           const gchar* content,
                                           guint timeout);
VALA_EXTERN void tuba_views_admin_page_base_on_error (TubaViewsAdminPageBase* self,
                                          gint code,
                                          const gchar* message);
VALA_EXTERN TubaViewsAdminPageBase* tuba_views_admin_page_base_new (void);
VALA_EXTERN TubaViewsAdminPageBase* tuba_views_admin_page_base_construct (GType object_type);
VALA_EXTERN void tuba_views_admin_page_base_set_page (TubaViewsAdminPageBase* self,
                                          GtkWidget* value);
VALA_EXTERN TubaDialogsAdminWindow* tuba_views_admin_page_base_get_admin_window (TubaViewsAdminPageBase* self);
VALA_EXTERN void tuba_views_admin_page_base_set_admin_window (TubaViewsAdminPageBase* self,
                                                  TubaDialogsAdminWindow* value);
VALA_EXTERN gboolean tuba_views_admin_page_base_get_spinning (TubaViewsAdminPageBase* self);
VALA_EXTERN void tuba_views_admin_page_base_set_spinning (TubaViewsAdminPageBase* self,
                                              gboolean value);
static GObject * tuba_views_admin_page_base_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties);
static void tuba_views_admin_page_base_finalize (GObject * obj);
static GType tuba_views_admin_page_base_get_type_once (void);
static void _vala_tuba_views_admin_page_base_get_property (GObject * object,
                                                    guint property_id,
                                                    GValue * value,
                                                    GParamSpec * pspec);
static void _vala_tuba_views_admin_page_base_set_property (GObject * object,
                                                    guint property_id,
                                                    const GValue * value,
                                                    GParamSpec * pspec);

static inline gpointer
tuba_views_admin_page_base_get_instance_private (TubaViewsAdminPageBase* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsAdminPageBase_private_offset);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_views_admin_page_base_real_add_to_page (TubaViewsAdminPageBase* self,
                                             AdwPreferencesGroup* group)
{
	AdwPreferencesPage* pref_page = NULL;
	GtkWidget* _tmp0_;
	AdwPreferencesPage* _tmp1_;
	AdwPreferencesPage* _tmp2_;
	g_return_if_fail (group != NULL);
	_tmp0_ = self->priv->_page;
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, adw_preferences_page_get_type ()) ? ((AdwPreferencesPage*) _tmp0_) : NULL);
	pref_page = _tmp1_;
	_tmp2_ = pref_page;
	if (_tmp2_ != NULL) {
		AdwPreferencesPage* _tmp3_;
		_tmp3_ = pref_page;
		adw_preferences_page_add (_tmp3_, group);
	}
	_g_object_unref0 (pref_page);
}

void
tuba_views_admin_page_base_add_to_page (TubaViewsAdminPageBase* self,
                                        AdwPreferencesGroup* group)
{
	TubaViewsAdminPageBaseClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = TUBA_VIEWS_ADMIN_PAGE_BASE_GET_CLASS (self);
	if (_klass_->add_to_page) {
		_klass_->add_to_page (self, group);
	}
}

void
tuba_views_admin_page_base_add_toast (TubaViewsAdminPageBase* self,
                                      const gchar* content,
                                      guint timeout)
{
	AdwToastOverlay* _tmp0_;
	AdwToast* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (content != NULL);
	_tmp0_ = self->priv->toast_overlay;
	_tmp1_ = adw_toast_new (content);
	adw_toast_set_timeout (_tmp1_, timeout);
	adw_toast_overlay_add_toast (_tmp0_, _tmp1_);
}

void
tuba_views_admin_page_base_on_error (TubaViewsAdminPageBase* self,
                                     gint code,
                                     const gchar* message)
{
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (message != NULL);
	_tmp0_ = string_to_string (message);
	_tmp1_ = g_strdup_printf ("%i", code);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_strconcat (_tmp0_, " ", _tmp2_, NULL);
	_tmp4_ = _tmp3_;
	tuba_views_admin_page_base_add_toast (self, _tmp4_, (guint) 5);
	_g_free0 (_tmp4_);
	_g_free0 (_tmp2_);
}

TubaViewsAdminPageBase*
tuba_views_admin_page_base_construct (GType object_type)
{
	TubaViewsAdminPageBase * self = NULL;
	self = (TubaViewsAdminPageBase*) g_object_new (object_type, NULL);
	return self;
}

TubaViewsAdminPageBase*
tuba_views_admin_page_base_new (void)
{
	return tuba_views_admin_page_base_construct (TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE);
}

GtkWidget*
tuba_views_admin_page_base_get_page (TubaViewsAdminPageBase* self)
{
	GtkWidget* result;
	GtkWidget* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_page;
	result = _tmp0_;
	return result;
}

void
tuba_views_admin_page_base_set_page (TubaViewsAdminPageBase* self,
                                     GtkWidget* value)
{
	GtkWidget* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_admin_page_base_get_page (self);
	if (old_value != value) {
		GtkWidget* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_page);
		self->priv->_page = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_admin_page_base_properties[TUBA_VIEWS_ADMIN_PAGE_BASE_PAGE_PROPERTY]);
	}
}

TubaDialogsAdminWindow*
tuba_views_admin_page_base_get_admin_window (TubaViewsAdminPageBase* self)
{
	TubaDialogsAdminWindow* result;
	TubaDialogsAdminWindow* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_admin_window;
	result = _tmp0_;
	return result;
}

void
tuba_views_admin_page_base_set_admin_window (TubaViewsAdminPageBase* self,
                                             TubaDialogsAdminWindow* value)
{
	TubaDialogsAdminWindow* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_admin_page_base_get_admin_window (self);
	if (old_value != value) {
		TubaDialogsAdminWindow* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_admin_window);
		self->priv->_admin_window = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_admin_page_base_properties[TUBA_VIEWS_ADMIN_PAGE_BASE_ADMIN_WINDOW_PROPERTY]);
	}
}

gboolean
tuba_views_admin_page_base_get_spinning (TubaViewsAdminPageBase* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_spinning;
	return result;
}

void
tuba_views_admin_page_base_set_spinning (TubaViewsAdminPageBase* self,
                                         gboolean value)
{
	g_return_if_fail (self != NULL);
	self->priv->_spinning = value;
	if (value) {
		GtkScrolledWindow* _tmp0_;
		AdwSpinner* _tmp1_;
		_tmp0_ = self->priv->scroller;
		_tmp1_ = self->priv->spinner;
		gtk_scrolled_window_set_child (_tmp0_, (GtkWidget*) _tmp1_);
	} else {
		GtkScrolledWindow* _tmp2_;
		GtkWidget* _tmp3_;
		_tmp2_ = self->priv->scroller;
		_tmp3_ = self->priv->_page;
		gtk_scrolled_window_set_child (_tmp2_, _tmp3_);
	}
	g_object_notify_by_pspec ((GObject *) self, tuba_views_admin_page_base_properties[TUBA_VIEWS_ADMIN_PAGE_BASE_SPINNING_PROPERTY]);
}

static GObject *
tuba_views_admin_page_base_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaViewsAdminPageBase * self;
	AdwHeaderBar* _tmp0_;
	AdwSpinner* _tmp1_ = NULL;
	AdwPreferencesPage* _tmp2_ = NULL;
	AdwPreferencesPage* _tmp3_;
	AdwSpinner* _tmp4_;
	GtkWidget* _tmp5_;
	GtkScrolledWindow* _tmp6_ = NULL;
	GtkScrolledWindow* _tmp7_;
	GtkWidget* _tmp8_;
	AdwToastOverlay* _tmp9_ = NULL;
	AdwToastOverlay* _tmp10_;
	GtkWidget* _tmp11_;
	AdwToolbarView* _tmp12_ = NULL;
	AdwToolbarView* _tmp13_;
	AdwHeaderBar* _tmp14_;
	AdwToolbarView* _tmp15_;
	parent_class = G_OBJECT_CLASS (tuba_views_admin_page_base_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBase);
	_tmp0_ = (AdwHeaderBar*) adw_header_bar_new ();
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->headerbar);
	self->headerbar = _tmp0_;
	_tmp1_ = (AdwSpinner*) adw_spinner_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp1_, GTK_ALIGN_CENTER);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp1_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp1_, TRUE);
	g_object_set ((GtkWidget*) _tmp1_, "height-request", 32, NULL);
	g_object_ref_sink (_tmp1_);
	_g_object_unref0 (self->priv->spinner);
	self->priv->spinner = _tmp1_;
	_tmp2_ = (AdwPreferencesPage*) adw_preferences_page_new ();
	gtk_widget_set_hexpand ((GtkWidget*) _tmp2_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp2_, TRUE);
	gtk_widget_set_valign ((GtkWidget*) _tmp2_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	tuba_views_admin_page_base_set_page (self, (GtkWidget*) _tmp3_);
	_g_object_unref0 (_tmp3_);
	_tmp4_ = self->priv->spinner;
	_tmp5_ = _g_object_ref0 ((GtkWidget*) _tmp4_);
	_tmp6_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	gtk_widget_set_vexpand ((GtkWidget*) _tmp6_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp6_, TRUE);
	gtk_scrolled_window_set_child (_tmp6_, _tmp5_);
	_g_object_unref0 (_tmp5_);
	g_object_ref_sink (_tmp6_);
	_g_object_unref0 (self->priv->scroller);
	self->priv->scroller = _tmp6_;
	_tmp7_ = self->priv->scroller;
	_tmp8_ = _g_object_ref0 ((GtkWidget*) _tmp7_);
	_tmp9_ = (AdwToastOverlay*) adw_toast_overlay_new ();
	gtk_widget_set_vexpand ((GtkWidget*) _tmp9_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp9_, TRUE);
	adw_toast_overlay_set_child (_tmp9_, _tmp8_);
	_g_object_unref0 (_tmp8_);
	g_object_ref_sink (_tmp9_);
	_g_object_unref0 (self->priv->toast_overlay);
	self->priv->toast_overlay = _tmp9_;
	_tmp10_ = self->priv->toast_overlay;
	_tmp11_ = _g_object_ref0 ((GtkWidget*) _tmp10_);
	_tmp12_ = (AdwToolbarView*) adw_toolbar_view_new ();
	adw_toolbar_view_set_content (_tmp12_, _tmp11_);
	_g_object_unref0 (_tmp11_);
	g_object_ref_sink (_tmp12_);
	_g_object_unref0 (self->toolbar_view);
	self->toolbar_view = _tmp12_;
	_tmp13_ = self->toolbar_view;
	_tmp14_ = self->headerbar;
	adw_toolbar_view_add_top_bar (_tmp13_, (GtkWidget*) _tmp14_);
	_tmp15_ = self->toolbar_view;
	adw_navigation_page_set_child ((AdwNavigationPage*) self, (GtkWidget*) _tmp15_);
	return obj;
}

static void
tuba_views_admin_page_base_class_init (TubaViewsAdminPageBaseClass * klass,
                                       gpointer klass_data)
{
	tuba_views_admin_page_base_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsAdminPageBase_private_offset);
	((TubaViewsAdminPageBaseClass *) klass)->add_to_page = (void (*) (TubaViewsAdminPageBase*, AdwPreferencesGroup*)) tuba_views_admin_page_base_real_add_to_page;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_views_admin_page_base_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_views_admin_page_base_set_property;
	G_OBJECT_CLASS (klass)->constructor = tuba_views_admin_page_base_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_admin_page_base_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ADMIN_PAGE_BASE_PAGE_PROPERTY, tuba_views_admin_page_base_properties[TUBA_VIEWS_ADMIN_PAGE_BASE_PAGE_PROPERTY] = g_param_spec_object ("page", "page", "page", gtk_widget_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ADMIN_PAGE_BASE_ADMIN_WINDOW_PROPERTY, tuba_views_admin_page_base_properties[TUBA_VIEWS_ADMIN_PAGE_BASE_ADMIN_WINDOW_PROPERTY] = g_param_spec_object ("admin-window", "admin-window", "admin-window", TUBA_DIALOGS_ADMIN_TYPE_WINDOW, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ADMIN_PAGE_BASE_SPINNING_PROPERTY, tuba_views_admin_page_base_properties[TUBA_VIEWS_ADMIN_PAGE_BASE_SPINNING_PROPERTY] = g_param_spec_boolean ("spinning", "spinning", "spinning", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_views_admin_page_base_instance_init (TubaViewsAdminPageBase * self,
                                          gpointer klass)
{
	self->priv = tuba_views_admin_page_base_get_instance_private (self);
	self->priv->_spinning = TRUE;
}

static void
tuba_views_admin_page_base_finalize (GObject * obj)
{
	TubaViewsAdminPageBase * self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBase);
	_tmp0_ = adw_navigation_page_get_title ((AdwNavigationPage*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = string_to_string (_tmp1_);
	_tmp3_ = g_strconcat ("Destroying Admin Dialog page: ", _tmp2_, NULL);
	_tmp4_ = _tmp3_;
	g_debug ("Base.vala:11: %s", _tmp4_);
	_g_free0 (_tmp4_);
	_g_object_unref0 (self->priv->_page);
	_g_object_unref0 (self->priv->scroller);
	_g_object_unref0 (self->priv->spinner);
	_g_object_unref0 (self->priv->toast_overlay);
	_g_object_unref0 (self->headerbar);
	_g_object_unref0 (self->toolbar_view);
	_g_object_unref0 (self->priv->_admin_window);
	G_OBJECT_CLASS (tuba_views_admin_page_base_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_admin_page_base_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsAdminPageBaseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_admin_page_base_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsAdminPageBase), 0, (GInstanceInitFunc) tuba_views_admin_page_base_instance_init, NULL };
	GType tuba_views_admin_page_base_type_id;
	tuba_views_admin_page_base_type_id = g_type_register_static (adw_navigation_page_get_type (), "TubaViewsAdminPageBase", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsAdminPageBase_private_offset = g_type_add_instance_private (tuba_views_admin_page_base_type_id, sizeof (TubaViewsAdminPageBasePrivate));
	return tuba_views_admin_page_base_type_id;
}

GType
tuba_views_admin_page_base_get_type (void)
{
	static GType tuba_views_admin_page_base_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_admin_page_base_type_id__once)) {
		GType tuba_views_admin_page_base_type_id;
		tuba_views_admin_page_base_type_id = tuba_views_admin_page_base_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_admin_page_base_type_id__once, tuba_views_admin_page_base_type_id);
	}
	return tuba_views_admin_page_base_type_id__once;
}

static void
_vala_tuba_views_admin_page_base_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec)
{
	TubaViewsAdminPageBase * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBase);
	switch (property_id) {
		case TUBA_VIEWS_ADMIN_PAGE_BASE_PAGE_PROPERTY:
		g_value_set_object (value, tuba_views_admin_page_base_get_page (self));
		break;
		case TUBA_VIEWS_ADMIN_PAGE_BASE_ADMIN_WINDOW_PROPERTY:
		g_value_set_object (value, tuba_views_admin_page_base_get_admin_window (self));
		break;
		case TUBA_VIEWS_ADMIN_PAGE_BASE_SPINNING_PROPERTY:
		g_value_set_boolean (value, tuba_views_admin_page_base_get_spinning (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_views_admin_page_base_set_property (GObject * object,
                                               guint property_id,
                                               const GValue * value,
                                               GParamSpec * pspec)
{
	TubaViewsAdminPageBase * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBase);
	switch (property_id) {
		case TUBA_VIEWS_ADMIN_PAGE_BASE_PAGE_PROPERTY:
		tuba_views_admin_page_base_set_page (self, g_value_get_object (value));
		break;
		case TUBA_VIEWS_ADMIN_PAGE_BASE_ADMIN_WINDOW_PROPERTY:
		tuba_views_admin_page_base_set_admin_window (self, g_value_get_object (value));
		break;
		case TUBA_VIEWS_ADMIN_PAGE_BASE_SPINNING_PROPERTY:
		tuba_views_admin_page_base_set_spinning (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

